aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorGisle Vanem <gvanem@broadpark.no>2011-04-20 15:23:57 +0200
committerDaniel Stenberg <daniel@haxx.se>2011-04-20 15:23:57 +0200
commit9039d19f01f2d201dd4dfeac5a81753c82c72147 (patch)
tree992d235675c65403ab97a9639dcc04138068a343
parentc828646f60b5bffb2bfcf924eba36da767bf08bf (diff)
CURL_DOES_CONVERSIONS: fixes
Made it compile and work again after the code move.
-rw-r--r--lib/non-ascii.c13
-rw-r--r--lib/non-ascii.h2
-rw-r--r--lib/transfer.c1
3 files changed, 12 insertions, 4 deletions
diff --git a/lib/non-ascii.h b/lib/non-ascii.h
index cccb11f25..89899bedd 100644
--- a/lib/non-ascii.h
+++ b/lib/non-ascii.h
@@ -26,7 +26,7 @@
#include "urldata.h"
/*
- * Curl_convertclone() returns a malloced copy of the source string (if
+ * Curl_convert_clone() returns a malloced copy of the source string (if
* returning CURLE_OK), with the data converted to network format.
*
* If no conversion was needed *outbuf may be NULL.
diff --git a/lib/transfer.c b/lib/transfer.c
index 08d5ed37f..1684a489f 100644
--- a/lib/transfer.c
+++ b/lib/transfer.c
@@ -103,6 +103,7 @@
#include "multiif.h"
#include "rtsp.h"
#include "connect.h"
+#include "non-ascii.h"
#define _MPRINTF_REPLACE /* use our functions only */
#include <curl/mprintf.h>
diff --git a/lib/non-ascii.c b/lib/non-ascii.c
index 945178e53..7e6ad37bf 100644
--- a/lib/non-ascii.c
+++ b/lib/non-ascii.c
@@ -24,6 +24,13 @@
#ifdef CURL_DOES_CONVERSIONS
+#include "non-ascii.h"
+#include "formdata.h"
+#include "sendf.h"
+#include "urldata.h"
+
+#include <curl/curl.h>
+
#ifdef HAVE_ICONV
#include <iconv.h>
/* set default codesets for iconv */
@@ -37,10 +44,10 @@
#endif /* HAVE_ICONV */
/*
* Curl_convertclone() returns a malloced copy of the source string (if
* returning CURLE_OK), with the data converted to network format.
*/
-CURLcode Curl_convertclone(struct SessionHandle *data,
+CURLcode Curl_convert_clone(struct SessionHandle *data,
const char *indata,
size_t insize,
char **outbuf)
@@ -54,7 +61,7 @@ CURLcode Curl_convertclone(struct SessionHandle *data,
memcpy(convbuf, indata, insize);
result = Curl_convert_to_network(data, convbuf, insize);
- if(result) {s
+ if(result) {
free(convbuf);
return result;
}
@@ -37,10 +44,10 @@
#endif /* HAVE_ICONV */
/*
- * Curl_convertclone() returns a malloced copy of the source string (if
+ * Curl_convert_clone() returns a malloced copy of the source string (if
* returning CURLE_OK), with the data converted to network format.
*/